fnss.topologies.randmodels.waxman_2_topology — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »

# fnss.topologies.randmodels.waxman_2_topology

`waxman_2_topology`(n, alpha=0.4, beta=0.1, domain=(0, 0, 1, 1), distance_unit='Km', seed=None)

  Return a Waxman-2 random topology.

  The Waxman-2 random topology models place n nodes uniformly at random in a rectangular domain. Two nodes u, v are connected with a link with probability

  where the distance d is the Euclidean distance between the nodes u and v. and L is the maximum distance between all nodes in the graph.

  Parameters : | n : int Number of nodes alpha : float Model parameter chosen in (0,1] (higher alpha increases link density) beta : float Model parameter chosen in (0,1] (higher beta increases difference between density of short and long links) domain : tuple of numbers, optional Domain size (xmin, ymin, xmax, ymax) seed : int, optional Seed for random number generator (default=None).
  Returns : | G : Topology

  Notes

  Each edge of G has the attribute length

  References

  [R23] | B. M. Waxman, Routing of multipoint connections. IEEE J. Select. Areas Commun. 6(9),(1988) 1617-1622.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »